Cup class

Cup is a class to wrap a Content object and List object.

Constructors

Cup(Content content, List<TapiocaBall> tapiocaBalls)
Creates a Cup object.

Properties

content → Content
Returns the Content instance for applying filters.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tapiocaBalls → List<TapiocaBall>
Returns the List<TapiocaBall> instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
suckUp(String destFilePath) → Future
Edit the video based on the tapiocaBalls(list of processing)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited